@@ -20,6 +20,7 @@ def get_multiline_text_size(
     :param font:
     :return: Tuple of width and height
     """
+    text_string = text_string.strip()
     if not text_string:
         return 0, 0
     # https://stackoverflow.com/a/46220683/9263761
@@ -115,6 +116,8 @@ def get_splitted_string(lesson: Timetable.Lesson, limit: int) -> str:
 
     string = '\n'.join(t_lines)
 
+    string = string.strip()
+
     return string
 
 
